@@ -10,58 +10,92 @@
 
   globalVariables(c(
     "add",
+    "alpha",
     "asp",
     "axes",
-    "by_continuous",
-    "by_ordered",
+    "bg",
+    "bubble",
+    "bubble_alpha",
+    "bubble_bg_alpha",
     "bubble_cex",
+    "by_continuous",
+    "by_dep",
+    "by_ordered",
+    "cex",
+    "cex_dep",
     "cex_fct_adj",
+    "data",
+    "datapoints",
     "dots",
     "draw",
+    "facet",
+    "facet.args",
+    "facet_attr",
     "facet_bg",
     "facet_border",
+    "facet_by",
     "facet_col",
     "facet_font",
     "facet_newlines",
     "facet_rect",
     "facet_text",
-    "facet.args",
-    "facet",
     "facets",
     "fill",
     "flip",
     "frame.plot",
     "has_legend",
+    "height",
     "iby",
     "ifacet",
+    "lty",
+    "lwd",
     "nfacet_cols",
     "nfacet_rows",
     "nfacets",
     "ngrps",
+    "null_by",
+    "null_facet",
+    "null_palette",
+    "null_xlim",
+    "null_ylim",
     "oxaxis",
     "oyaxis",
+    "pch",
     "ribbon.alpha",
     "split_data",
     "tpars",
     "type",
+    "type_info",
+    "was_area_type",
+    "width",
     "x",
+    "x_by",
+    "x_dep",
+    "xaxb",
     "xaxl",
     "xaxs",
     "xaxt",
+    "xlab",
     "xlabs",
     "xlim",
-    "xlim_user",
     "xlvls",
     "xmax",
+    "xmax_dep",
     "xmin",
+    "xmin_dep",
     "y",
+    "y_dep",
+    "yaxb",
     "yaxl",
     "yaxs",
     "yaxt",
+    "ygroup",
+    "ylab",
     "ylabs",
     "ylim",
-    "ylim_user",
     "ymax",
-    "ymin"
+    "ymax_dep",
+    "ymin",
+    "ymin_dep"
   ))
 }
